-- For the Faction - Options Menu
--
-- Thanks to Ami_Yuy of the fantastic Can I Mog It addon, 
-- who did the hard work of learning how to make option menus,
-- from the work of Stanzilla and Semlar on AdvancedInterfaceOptions.
-- Both of said addons kick ass, and I'm a big fan of them. You should check them out.

local _G = _G

ForTheFaction_OptionsVersion = "1.02"
local faction = "Your Faction"

if UnitFactionGroup("player") == "Horde" then
	faction = "the Horde"
else
	if UnitFactionGroup("player") == "Alliance" then
		faction = "the Alliance"
	end
end

ForTheFaction_Defaults = {
    ["options"] = {
        ["version"] = ForTheFaction_OptionsVersion,
        ["BuffPride"] = true,
        ["PvPPride"] = false,
		["LevelUpPride"] = true,
		["AchievementPride"] = true,
		["QuestCompletionBasedPride"] = false,
    },
}

ForTheFaction_DisplayData = {
    ["BuffPride"] = {
        ["displayName"] = "Use /forthe with Haste Buffs",
        ["description"] = "Shout For " .. faction .."!  when a Raid Buff like Heroism/Bloodlust is activated."
    },
    ["PvPPride"] = {
        ["displayName"] = "Use /forthe on Honorable Kills",
        ["description"] = "Shout For ".. faction .."! when getting an honorable kill."
    },
	["LevelUpPride"] = {
        ["displayName"] = "Use /forthe on Level Up",
        ["description"] = "Shout For ".. faction .."! when reaching a new level."
    },
	["AchievementPride"] = {
        ["displayName"] = "Use /forthe on gaining a new Achievement",
        ["description"] = "Shout For ".. faction .."! when earning a new achievement."
    },
	["QuestCompletionBasedPride"] = {
        ["displayName"] = "Require story quest completion for hero classes. (Death Knights)",
        ["description"] = "Requires 'Where Kings Walk' or 'Warchief's Blessing' for Death Knights.\nRequires 'Illidari, We Are Leaving' for Demon Hunters.\n Requires /reload or /ft to update instantly."
    },
	
}

ForTheFaction.frame = CreateFrame("Frame", "ForTheOptionsFrame", UIParent);
ForTheFaction.frame.name = "For the Faction";
ForTheFaction.frame:RegisterEvent("ADDON_LOADED")
InterfaceOptions_AddCategory(ForTheFaction.frame);

ForTheFaction.frame:SetScript("OnEvent", function(self, event, addonName)
    if event == "ADDON_LOADED" and addonName == "ForTheFaction" then
        ForTheFaction.frame.Loaded()
    end
end)

local function checkboxOnClick(self)
	local checked = self:GetChecked()
	PlaySound(checked and "igMainMenuOptionCheckBoxOn" or "igMainMenuOptionCheckBoxOff")
	self:SetValue(checked)
end


local function newCheckbox(parent, variableName)
    local displayData = ForTheFaction_DisplayData[variableName]
    local checkbox = CreateFrame("CheckButton", "ForTheFactionCheckbox" .. variableName, 
            parent, "InterfaceOptionsCheckButtonTemplate")


    checkbox.GetValue = function (self)
        return ForTheFactionOptions[variableName]
    end
    checkbox.SetValue = function (self, value) ForTheFactionOptions[variableName] = value end

    checkbox:SetScript("OnClick", checkboxOnClick)
    checkbox:SetChecked(checkbox:GetValue())

    checkbox.label = _G[checkbox:GetName() .. "Text"]
    checkbox.label:SetText(displayData["displayName"])

    checkbox.tooltipText = displayData["displayName"]
    checkbox.tooltipRequirement = displayData["description"]
    return checkbox
end


local function createOptionsMenu()
	-- Giving our Options a title
	local Title = ForTheOptionsFrame:CreateFontString(nil, 'ARTWORK', 'GameFontNormalLarge')
	Title:SetJustifyV('TOP')
	Title:SetJustifyH('LEFT')
	Title:SetPoint('TOPLEFT', 16, -16)
	Title:SetText("For the Faction")
	
	-- Giving some description.
	local Desc = ForTheOptionsFrame:CreateFontString(nil, 'ARTWORK', 'GameFontNormal')
	Desc:SetMaxLines(3)
	Desc:SetNonSpaceWrap(true)
	Desc:SetJustifyV('TOP')
	Desc:SetJustifyH('LEFT')
	Desc:SetPoint('TOPLEFT', Title, 'BOTTOMLEFT', 0, -8)
	Desc:SetPoint('RIGHT', -32, 0)
	Desc:SetText('These options allow you to decide in which circumstances /forthe command triggers.')

    -- Makin' and placin' the checkboxes.
    local BuffPride = newCheckbox(ForTheFaction.frame, "BuffPride")
	local PvPPride = newCheckbox(ForTheFaction.frame, "PvPPride")
	local LevelUpPride = newCheckbox(ForTheFaction.frame, "LevelUpPride")
	local AchievementPride = newCheckbox(ForTheFaction.frame, "AchievementPride")
	local QuestCompletionBasedPride = newCheckbox(ForTheFaction.frame, "QuestCompletionBasedPride")
	
    BuffPride:SetPoint("TOPLEFT", Desc, "BOTTOMLEFT")
	PvPPride:SetPoint("TOPLEFT", BuffPride, "BOTTOMLEFT")
	LevelUpPride:SetPoint("TOPLEFT", PvPPride, "BOTTOMLEFT")
	AchievementPride:SetPoint("TOPLEFT", LevelUpPride, "BOTTOMLEFT")
	
	local Desc2 = ForTheOptionsFrame:CreateFontString(nil, 'ARTWORK', 'GameFontNormal')
	Desc2:SetMaxLines(3)
	Desc2:SetNonSpaceWrap(true)
	Desc2:SetJustifyV('TOP')
	Desc2:SetJustifyH('LEFT')
	Desc2:SetPoint('TOPLEFT', AchievementPride, 'BOTTOMLEFT', 0, -8)
	Desc2:SetPoint('RIGHT', -32, 0)
	Desc2:SetText('Immersion Options')
	QuestCompletionBasedPride:SetPoint("TOPLEFT", Desc2, "BOTTOMLEFT")
end


function ForTheFaction.frame.Loaded()
    -- Load up the options from defaults.
    if (not ForTheFactionOptions) then
        ForTheFactionOptions = ForTheFaction_Defaults.options
        print("ForTheFactionOptions not found, loading defaults!")
    end
    -- I think it only takes missing options from defaults if version number doesn't match.
    if (ForTheFactionOptions["version"] < ForTheFaction_OptionsVersion) then
        ForTheFactionOptions_temp = ForTheFaction_Defaults.options;
        for k,v in pairs(ForTheFactionOptions) do
            if (ForTheFaction_Defaults.options[k]) then
                ForTheFactionOptions_temp[k] = v;
            end
        end
        ForTheFactionOptions_temp["version"] = ForTheFaction_OptionsVersion;
        ForTheFactionOptions = ForTheFactionOptions_temp;
    end
    createOptionsMenu()
end
